@@ -3,4 +3,4 @@
 from extra_settings import settings
 
 
-default_app_config = 'extra_settings.apps.ExtraSettingsConfig'
+default_app_config = "extra_settings.apps.ExtraSettingsConfig"
